@@ -27,21 +27,23 @@ pnadc_labeller <- function(data_pnadc,dictionary.file){
       codcurrent <- dictionary$X__3[i]
     }
   }
-  notlabel <- c("Ano","Trimestre","UPA","Estrato","V1008","V1014","V1016","posest",
-                "V2003","V2008","V20081","V20082","V40081","V40082","V40083","V4010",
-                "V4013","V4041","V4044")
+  notlabel <- c("Ano", "Trimestre", "UPA", "Estrato", "V1008",
+                "V1014", "V1016", "posest", "V2003", "V2008", "V20081",
+                "V20082", "V40081", "V40082", "V40083", "V4010", "V4013",
+                "V4041", "V4044","V4075A1","VD4031","VD4035")
   vars <- names(data_pnadc)
-  varsc <- vars[sapply(data_pnadc,class)=="character"]
-  varsf <- setdiff(varsc,notlabel)
-  for(i in 1:length(varsf)){
-    if(varsf[i] %in% (dictionary$X__3)){
-      data_pnadc[varsf[i]] <- factor(unlist(data_pnadc[varsf[i]]),
-                              levels=unlist(dictionary %>%
-                                           subset(X__3 == varsf[i])%>%
-                                           select(X__6)),
-                              labels=unlist(dictionary %>%
-                                           subset(X__3 == varsf[i])%>%
-                                           select(X__7)))
+  varsc <- vars[sapply(data_pnadc, class) == "character"]
+  varsf <- setdiff(varsc, notlabel)
+  for (i in 1:length(varsf)) {
+    if (varsf[i] %in% (dictionary$X__3)) {
+      data_pnadc[varsf[i]] <- factor(as.numeric(unlist(data_pnadc[varsf[i]])),
+                                     levels = suppressWarnings(
+                                       as.numeric(unlist(dictionary %>%
+                                              subset(X__3 == varsf[i]) %>%
+                                              select(X__6)))),
+                                     labels = unlist(dictionary %>%
+                                              subset(X__3 == varsf[i]) %>%
+                                              select(X__7)))
     }
   }
   return(data_pnadc)
